@@ -1,12 +1,13 @@
+import configparser
 import copy
+import datetime
 import json
+import os
 import pprint
 import shutil
 import time
 from zipfile import ZipFile
-import os
 
-import configparser
 import requests
 from ptoolbox.dsa import dsa_problem_file
 from ptoolbox.dsa.dsa_problem import DsaProblem
@@ -46,7 +47,7 @@ def prepare_testcases_from_file(tc_file, testcase_output_folder, start_number=0)
     testcases = dsa_problem_file.read_testcases_from_file(tc_file)
 
     for i in range(len(testcases)):
-        save_testcase_file(testcase_output_folder, start_number+i, testcases[i]['input'], testcases[i]['output'])
+        save_testcase_file(testcase_output_folder, start_number + i, testcases[i]['input'], testcases[i]['output'])
 
     return start_number + len(testcases)
 
@@ -181,6 +182,44 @@ class HackerRank:
 
         return True
 
+    def create_contest(self, name):
+        timestamp = datetime.datetime.now().timestamp() + 3600 * 24
+        data = {"name": name, "starttime": timestamp, "endtime": None,
+                "description": "Please provide a short description of your contest here\u0021 This will also be used as metadata.",
+                "scoring": "- Each challenge has a pre-determined score.\\n- A participant’s score depends on the number of test cases a participant’s code submission successfully passes.\\n- If a participant submits more than one solution per challenge, then the participant’s score will reflect the highest score achieved. In a game challenge, the participant\'s score will reflect the last code submission.\\n- Participants are ranked by score. If two or more participants achieve the same score, then the tie is broken by the total time taken to submit the last solution resulting in a higher score",
+                "prizes": "- Prizes are optional. You may add any prizes that you would like to offer here.",
+                "rules": "- Please provide any rules for your contest here.",
+                "slug": None,
+                "organization_type": "school",
+                "organization_name": "Ucode.vn",
+                "is_multi_round": False,
+                "tagline": None,
+                "use_background_image_as_og": None,
+                "homepage_background_image": None,
+                "homepage_background_image_name": None}
+
+        url = 'https://www.hackerrank.com/rest/administration/contests'
+
+        headers = copy.deepcopy(self._headers)
+        headers['x-csrf-token'] = self.csrf_token
+        headers['referer'] = 'https://www.hackerrank.com/administration/contests/create'
+
+        print('creating contest:')
+        print(data)
+
+        r = self.s.post(url, json=data, headers=headers)
+
+        print(r.status_code)
+        print(r.headers)
+        print(r.text)
+
+        raw = r.json()
+        if not raw['status']:
+            print(raw['errors'])
+            raise ValueError("Cannot create contest")
+        # problem = self.parse_problem(raw)
+        return raw['model']
+
     def get_raw_track(self, track_url, offset=0, limit=10, save_to_file=None):
         # hackkerrank chi co lay 50 cai 1
         size = min(limit, 50)
@@ -430,7 +469,7 @@ class HackerRank:
         # problem = self.parse_problem(raw)
 
         if problem.languages:
-            url = 'https://www.hackerrank.com/rest/administration/challenges/{}/allowed_languages'\
+            url = 'https://www.hackerrank.com/rest/administration/challenges/{}/allowed_languages' \
                 .format(problem.src_id)
             data = []
             for lang in problem.languages:
@@ -508,7 +547,7 @@ class HackerRank:
         :param sample_ids: list of testcase ids to mark as sample
         :return:
         """
-        url = 'https://www.hackerrank.com/rest/administration/challenges/{}/test_cases/{}'\
+        url = 'https://www.hackerrank.com/rest/administration/challenges/{}/test_cases/{}' \
             .format(problem_id, ','.join([str(t) for t in testcase_ids]))
         print('Updating testcase score... {}'.format(url))
 
@@ -582,18 +621,21 @@ class HackerRankTrack:
 if __name__ == "__main__":
     # prepare_testcases("../problems/prob1", True)
     hr = HackerRank()
-    hr.login('thucngch', '15041985')
+    # hr.login('thucngch', '15041985')       # ucodevn02
+    # hr.login('nguyenchithuc', 'ngoaho85')  # ucodet02
+    hr.login('ucodevn', 'ucode@123')         # ucode02
 
-    problem_dir = '/home/thuc/teko/online-judge/ptoolbox/problems/array001_counting_sort3'
-
-    problem1 = DsaProblem.load(problem_dir)
-
-    problem1 = hr.update_problem('113357', problem1)
-    # problem1 = hr.create_problem(problem1)
-    # print('HackerrankID:', problem1.src_id)
-    # 113357
-
-    prepare_testcases(problem_dir)
-    testcase_zip = os.path.join(problem_dir, 'testcases_hackerrank.zip')
-    created_testcases = hr.upload_testcases_and_set_score('113357', testcase_zip, 50, 4)
+    hr.create_contest("ucode")
 
+    # problem_dir = '/home/thuc/teko/online-judge/ptoolbox/problems/array001_counting_sort3'
+    #
+    # problem1 = DsaProblem.load(problem_dir)
+    #
+    # problem1 = hr.update_problem('113357', problem1)
+    # # problem1 = hr.create_problem(problem1)
+    # # print('HackerrankID:', problem1.src_id)
+    # # 113357
+    #
+    # prepare_testcases(problem_dir)
+    # testcase_zip = os.path.join(problem_dir, 'testcases_hackerrank.zip')
+    # created_testcases = hr.upload_testcases_and_set_score('113357', testcase_zip, 50, 4)
