@@ -22,7 +22,7 @@ def make_slug(s):
 
 def make_problem_code(name):
     name = make_slug(name)
-    name = name.strip(" _")
+    name = name.strip(" _").replace("-", "_")
     if '0' <= name[0] <= '9':
         name = "p" + name
     return name
\ No newline at end of file
