@@ -192,9 +192,9 @@ if __name__ == "__main__":
         "connect.sid=s%3ABIXcPR3N1fqg6-Q95N431rGktezZS9tL.o6GU8PWzP4eLBvC%2Bgo5rczm4dVSwJwFhK%2FNaChC1Qns; " \
         "_gat=1; ajs_user_id=816683"
     repl = ReplIt(cookies)
-    classroom, problems = repl.get_classroom(classroom_id=156829, get_assignments=True, get_all_problems=True)
+    classroom, problems = repl.get_classroom(classroom_id=199129, get_assignments=True, get_all_problems=True)
     for problem in problems:
-        DsaProblem.save(problem, "../../problems/turtle")
+        DsaProblem.save(problem, "../../problems/lesson01")
     # print(classroom)
     # for assignment in classroom.assignments:
     #     print(assignment)
